pub enum InputBackendType {
Reedline,
Basic,
Minimal,
}Expand description
Identifies the input backend to use for the shell.
Variants
Reedline
Richest input backend, based on reedline.
Basic
Basic input backend that provides minimal completion support for testing.
Minimal
Most minimal input backend.