load_config

Function load_config 

pub fn load_config(
    disabled: bool,
    explicit_path: Option<&Path>,
) -> ConfigLoadResult
Loads configuration based on the provided options.

Arguments

  • disabled - If true, skip loading and return defaults
  • explicit_path - If provided, use this path instead of the default

Returns

A ConfigLoadResult containing the configuration and any errors encountered. If explicit_path is provided and loading fails, the result will have explicit_path: true to indicate that the error should be treated as fatal.