pub struct ConfigLoadResult {
pub config: Config,
pub path: Option<PathBuf>,
pub error: Option<ConfigLoadError>,
pub explicit_path: bool,
}Expand description
Result of attempting to load a configuration file.
Fields
config: ConfigThe loaded configuration, or default if loading failed.
path: Option<PathBuf>The path that was used (or attempted) for loading.
error: Option<ConfigLoadError>Any error that occurred during loading.
explicit_path: boolWhether the path was explicitly provided by the user (via --config).
Implementations
Sourceimpl ConfigLoadResult
impl ConfigLoadResult
Sourcepub fn into_config_or_log(self) -> Result<Config, String>
pub fn into_config_or_log(self) -> Result<Config, String>
Consumes the result and returns the configuration.
If an error occurred:
- For explicit paths (user-provided via
--config): returnsErrwith a formatted error - For default paths: logs a warning and returns the default configuration
Errors
Returns an error if an explicit config path was provided and loading failed.